==> react-ui-library-7.0.0.tgz: package/src/stories/segmented-control-story.js <==
import React, {Component} from 'react'
import {storiesOf} from '@kadira/storybook'
import {
  App,
  Pane,
  SegmentedControl,
  theme
} from '../components'
import Content from './Content'
const {majorScale} = theme

class SegmentedControlExample extends Component {
  constructor () {
    super()

    this.options = [
      {label: 'Hourly', value: 'hourly'},
      {label: 'Daily', value: 'daily'},
      {label: 'Monthly', value: 'monthly'}
    ]

    this.state = {
      value: this.options[1].value
    }
  }

  render () {
    const {value} = this.state

    return (
      <Pane display='flex' flexDirection='column' alignItems='center'>
        <SegmentedControl
          options={this.options}
          value={value}
          onChange={(value) => this.setState({value})}
          width={majorScale(40)}
        />
        <Pane marginY={majorScale(1)}>
          {value}
        </Pane>
      </Pane>
    )
  }
}

export default function buttonStory (module) {
  storiesOf('SegmentedControl', module)
    .add('usage', () => (
      <App>
        <Pane white padding={majorScale(10)}>
          <Content markdown>
            {`
# SegmentedControl

The SegmentedControl component, it's a fancy radio. Implements \`<Box />\`.

Uses regular \`input[type=radio]\`'s under the hood.

\`\`\`
class SegmentedControlExample extends Component {
  constructor () {
    super()

    this.options = [
      {label: 'Hourly', value: 'hourly'},
      {label: 'Daily', value: 'daily'},
      {label: 'Monthly', value: 'monthly'}
    ]

    this.state = {
      value: this.options[1].value
    }
  }

  render () {
    const {value} = this.state

    return (
      <Pane display='flex' flexDirection='column' alignItems='center'>
        <SegmentedControl
          options={this.options}
          value={value}
          onChange={(value) => this.setState({value})}
          width={majorScale(40)}
        />
        <Pane marginY={majorScale(1)}>
          {value}
        </Pane>
      </Pane>
    )
  }
}
\`\`\`
`}
          </Content>

          <SegmentedControlExample />

          <Content markdown>
            {`
prop | version | type | default | description
-----|---------|------| --------|----------
\`options\`| v7.0.0 | \`[ { label: node, value: string } ]\` | \`undefined\` | array of options to render
\`size\`| v7.0.0 | \`default\`, \`small\` | \`default\` | [optional] as defined by \`theme.controlSizes\`
\`name\`| v7.0.0 | \`string\` | \`SegmentedControl-*\` | [optional] \`name\` of the \`input[type=radio]\`'s
\`value\`| v7.0.0 | \`string\` | \`undefined\` | [optional] sets the active option. setting this makes it a controlled input
\`defaultValue\`| v7.0.0 | \`string\` | \`undefined\` | [optional] sets the default active option
\`onChange\`| v7.0.0 | \`function\` | \`undefined\` | [optional] callback passed the value of the new active option
`}
          </Content>
        </Pane>
      </App>
    ))
}

==> react-ui-library-7.4.0.tgz: package/src/stories/segmented-control-story.js <==
import React, {Component} from 'react'
import {storiesOf} from '@kadira/storybook'
import {
  App,
  Pane,
  SegmentedControl,
  theme
} from '../components'
import Content from './Content'
const {majorScale} = theme

class SegmentedControlExample extends Component {
  constructor () {
    super()

    this.options = [
      {label: 'Hourly', value: 'hourly'},
      {label: 'Daily', value: 'daily'},
      {label: 'Monthly', value: 'monthly'}
    ]

    this.state = {
      value: this.options[1].value
    }
  }

  render () {
    const {value} = this.state

    return (
      <Pane display='flex' flexDirection='column' alignItems='center'>
        <SegmentedControl
          options={this.options}
          value={value}
          onChange={(value) => this.setState({value})}
          width={majorScale(40)}
        />
        <Pane marginY={majorScale(1)}>
          {value}
        </Pane>
      </Pane>
    )
  }
}

export default function (module) {
  storiesOf('SegmentedControl', module)
    .add('usage', () => (
      <App>
        <Pane white padding={majorScale(10)}>
          <Content markdown>
            {`
# SegmentedControl

The SegmentedControl component, it's a fancy radio. Implements \`<Box />\`.

Uses regular \`input[type=radio]\`'s under the hood.

\`\`\`
class SegmentedControlExample extends Component {
  constructor () {
    super()

    this.options = [
      {label: 'Hourly', value: 'hourly'},
      {label: 'Daily', value: 'daily'},
      {label: 'Monthly', value: 'monthly'}
    ]

    this.state = {
      value: this.options[1].value
    }
  }

  render () {
    const {value} = this.state

    return (
      <Pane display='flex' flexDirection='column' alignItems='center'>
        <SegmentedControl
          options={this.options}
          value={value}
          onChange={(value) => this.setState({value})}
          width={majorScale(40)}
        />
        <Pane marginY={majorScale(1)}>
          {value}
        </Pane>
      </Pane>
    )
  }
}
\`\`\`
`}
          </Content>

          <SegmentedControlExample />

          <Content markdown>
            {`
prop | version | type | default | description
-----|---------|------| --------|----------
\`options\`| v7.0.0 | \`[ { label: node, value: string } ]\` | \`undefined\` | array of options to render
\`size\`| v7.0.0 | \`default\`, \`small\` | \`default\` | [optional] as defined by \`theme.controlSizes\`
\`name\`| v7.0.0 | \`string\` | \`SegmentedControl-*\` | [optional] \`name\` of the \`input[type=radio]\`'s
\`value\`| v7.0.0 | \`string\` | \`undefined\` | [optional] sets the active option. setting this makes it a controlled input
\`defaultValue\`| v7.0.0 | \`string\` | \`undefined\` | [optional] sets the default active option
\`onChange\`| v7.0.0 | \`function\` | \`undefined\` | [optional] callback passed the value of the new active option
`}
          </Content>
        </Pane>
      </App>
    ))
}
